@@ -6,9 +6,10 @@ from requests import Session
 
 # noinspection PyTypeChecker
 class AuthSession(Session):
-    def __init__(self, filename, cookies={}, headers={}):
+    def __init__(self, name=None, cookies={}, headers={}):
+        cookie_name = name if name else self.cookie_name
         self.cookie_path = os.path.expanduser(
-            os.path.join('~', '.xduauth', 'cookies', filename)
+            os.path.join('~', '.xduauth', 'cookies', cookie_name)
         )
         os.makedirs(os.path.dirname(self.cookie_path), exist_ok=True)
         if not cookies and hasattr(self, 'cookies'):
